SystemOrganization addCategory: #GoogleStaticMap!
SystemOrganization addCategory: #'GoogleStaticMap-Examples'!

WAImageTag subclass: #GMStaticMap
	instanceVariableNames: 'longitude latitude zoom mobile mapType scale path imageFormat markerGroups'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GoogleStaticMap'!

!GMStaticMap commentStamp: '<historical>' prior: 0!
GMStaticMap has not been documented yet. The class comment should describe the purpose of the class, its collaborations and its variables.

Instance Variables:
	longitude		<Float>
	latitude			<Float>
	type			<String>
	zoom			<Integer>
	mobile			<Boolean>
	path			<GMStaticMapPath>
	imageFormat	<String>
	markerGroups	<Collection of GMStaticMapPointGroup!

!GMStaticMap class methodsFor: 'constants' stamp: 'rs 3/29/2010 16:01'!
supportedImageFormats
	"Return a list of all image formats allowed for static maps" 

	^#('png' 'png8' 'png32' 'gif' 'jpg' 'jpg-baseline')
! !

!GMStaticMap class methodsFor: 'constants' stamp: 'RichardStern 12/6/2010 11:22'!
supportedMapTypes
	"Return a list of all map type values allowed for static maps" 

	^#('roadmap' 'satellite' 'terrain' 'hybrid')
! !

!GMStaticMap class methodsFor: 'constants' stamp: 'rs 7/29/2013 08:14'!
supportedScaleValues
	"Return a list of all scale values allowed for static maps" 

	^#(1 2 4)
! !

!GMStaticMap methodsFor: 'public' stamp: 'RichardStern 12/31/2010 12:48'!
addMarkerGroup: aGMStaticMapMarkerGroup
	"Add passed marker group to receiver"
	
	self markerGroups add: aGMStaticMapMarkerGroup.! !

!GMStaticMap methodsFor: 'public' stamp: 'RichardStern 12/31/2010 12:48'!
addMarkerGroups: aCollOfMarkerGroups
	"Add all passed marker groups to receiver"

	aCollOfMarkerGroups do: [:m| self addMarkerGroup: m].! !

!GMStaticMap methodsFor: 'private-url assembling' stamp: 'rs 7/25/2013 08:57'!
addMarkersToUrl: aWAUrl
	"Add markers to the passed map url"
	"In difference to former API versions, equal looking markers are
	now stored as groups - add each group to URL here"	

	self hasMarkers ifTrue:
	[
		self markerGroups do: 
		[:m | | stream |	
			stream := WriteStream on: String new.
			m asUrlParameterOn: stream.
			aWAUrl addField: 'markers' value: stream contents.
		].
	].
! !

!GMStaticMap methodsFor: 'private-url assembling' stamp: 'rs 7/25/2013 09:01'!
addPositionAndExtentParametersToUrl: aWAUrl
	"To the URL, add all the different config parameters controlling the position 
	and size of the map"

	self hasCenter ifTrue: [ aWAUrl addField: 'center' value: self mapCenter.].	
	self hasSize ifTrue: [ aWAUrl addField: 'size' value: self mapSize.].
	self hasScale ifTrue: [aWAUrl addField: 'scale' value: self scale.].
	self hasZoom ifTrue: [ aWAUrl addField: 'zoom' value: self zoom.].		
			
! !

!GMStaticMap methodsFor: 'private-testing' stamp: 'RichardStern 12/31/2010 12:55'!
hasCenter
	"Return whether map has center defined, ie, both longitude and latitude value are set"
	
	^(self longitude~~nil) and: [self latitude~~nil].! !

!GMStaticMap methodsFor: 'private-testing' stamp: 'RichardStern 12/31/2010 12:55'!
hasImageFormat
	"Return whether target format for imag ehas been set"
	
	^(self imageFormat~~nil).! !

!GMStaticMap methodsFor: 'private-testing' stamp: 'rs 7/25/2013 08:52'!
hasMapType
	"Return wheter a map type was quoted for receiver"
	
	^(self mapType~~nil).! !

!GMStaticMap methodsFor: 'private-testing' stamp: 'RichardStern 12/31/2010 12:55'!
hasMarkers
	"Return whether receiver involves any markers"
	
	^(self markerGroups~~nil) and: [self markerGroups isEmpty not].! !

!GMStaticMap methodsFor: 'private-testing' stamp: 'RichardStern 12/31/2010 12:55'!
hasPath
	"Return whether receiver show a path (ie, a polyline) on the map"
	
	^(self path~~nil)! !

!GMStaticMap methodsFor: 'private-testing' stamp: 'rs 7/25/2013 08:24'!
hasScale
	"Return wheter a scale was quoted for receiver"
	
	^(self scale~~nil).! !

!GMStaticMap methodsFor: 'private-testing' stamp: 'RichardStern 12/31/2010 12:56'!
hasSize
	"Return whether map has size defined, ie, both width and height value are set"
		
	^(self width~~nil) and: [self height~~nil].! !

!GMStaticMap methodsFor: 'private-testing' stamp: 'RichardStern 12/31/2010 12:56'!
hasZoom
	"Return wheter a zoom level was quoted for receiver"
	
	^(self zoom~~nil).! !

!GMStaticMap methodsFor: 'private-image attributes' stamp: 'rs 7/25/2013 08:49'!
height
	"Return the height of the map - which is a property inherited from image tag"
	"Means that map is always as big as the image tag itself - though they could have
	different extents in theory. So not fully consitent, but same size is usually the intention"	
	
	^self attributes at: 'height' ifAbsent: [nil].
! !

!GMStaticMap methodsFor: 'public' stamp: 'rs 7/25/2013 08:38'!
hybridMap 
	"Set hybrid (satellite+map) display mode for the map"
	
	self mapType: 'hybrid'! !

!GMStaticMap methodsFor: 'accessing' stamp: 'rs 3/29/2010 16:00'!
imageFormat
	^ imageFormat! !

!GMStaticMap methodsFor: 'accessing' stamp: 'rs 3/29/2010 16:00'!
imageFormat: anObject
	imageFormat := anObject! !

!GMStaticMap methodsFor: 'private-url assembling' stamp: 'rs 7/29/2013 08:10'!
imageUrl
	"Assemble the url-attribute of the image tag. This is the central method responsible for actually 
	getting an url according to Google static maps API that finally gets the map image "
	
	| url |

	"Get the basic URL for the API"
	url := WAUrl new
			scheme: 'http';
			host: 'maps.google.com';
			addToPath: 'maps/api/staticmap'.

	"To the URL, add all the different config parameters (if defined)"
	self addPositionAndExtentParametersToUrl: url.

	"Add url parameters controlling image format and map type"
	self hasImageFormat
		ifTrue: [ url addField: 'format' value: self imageFormat.].	
	self hasMapType
		ifTrue: [ url addField: 'maptype' value: self mapType.].	
			
	"Add sensor parameter. This is mandatory for all map request and therefore
	assumed false by default. ( GPS sensor support not considered yet)"
	 url addField: 'sensor' value: 'false'.
			
	"Add any markers and paths defined for receiver"
	self addMarkersToUrl: url.
	self hasPath ifTrue: [ self path addYourselfToUrl: url.].	

	^url! !

!GMStaticMap methodsFor: 'initializing' stamp: 'RichardStern 12/6/2010 14:25'!
initialize
	super initialize.
	
	markerGroups := OrderedCollection new.
	mobile := false.
	! !

!GMStaticMap methodsFor: 'accessing' stamp: 'rs 12/23/2008 15:17'!
latitude
	^ latitude! !

!GMStaticMap methodsFor: 'accessing' stamp: 'rs 12/23/2008 15:17'!
latitude: anObject
	latitude := anObject! !

!GMStaticMap methodsFor: 'accessing' stamp: 'rs 12/23/2008 15:17'!
longitude
	^ longitude! !

!GMStaticMap methodsFor: 'accessing' stamp: 'rs 12/23/2008 15:17'!
longitude: anObject
	longitude := anObject! !

!GMStaticMap methodsFor: 'private-map attributes' stamp: 'rs 7/25/2013 08:51'!
mapCenter
	"Return the center of the map expressed in geocoordinate string - e.g. '16.64,14.88'"
	
	^self latitude asString,',',self longitude asString.! !

!GMStaticMap methodsFor: 'private-map attributes' stamp: 'RichardStern 12/31/2010 12:53'!
mapSize
	"Return map size - which is a string liek e.g. '600x400''" 
	
	^(self attributes at: 'width') asString,'x',((self attributes at: 'height') asString).! !

!GMStaticMap methodsFor: 'accessing' stamp: 'rs 7/25/2013 08:50'!
mapType
	^ mapType! !

!GMStaticMap methodsFor: 'accessing' stamp: 'rs 7/25/2013 08:50'!
mapType: anObject
	mapType := anObject! !

!GMStaticMap methodsFor: 'accessing' stamp: 'RichardStern 12/6/2010 14:30'!
markerGroups
	^ markerGroups! !

!GMStaticMap methodsFor: 'accessing' stamp: 'RichardStern 12/6/2010 14:30'!
markerGroups: aCollection
	markerGroups := aCollection! !

!GMStaticMap methodsFor: 'private-url assembling' stamp: 'rs 7/25/2013 08:56'!
openTag
	"Override superclass to customize the tag output in order to put
	a target url that retrieves the map"
	
	self url: self imageUrl.
	super openTag! !

!GMStaticMap methodsFor: 'accessing' stamp: 'rs 1/12/2010 14:58'!
path
	^ path! !

!GMStaticMap methodsFor: 'accessing' stamp: 'rs 1/12/2010 14:58'!
path: anObject
	path := anObject! !

!GMStaticMap methodsFor: 'public' stamp: 'rs 7/25/2013 08:38'!
roadMap
	"Configure map to be shown as road map"
	
	self mapType: 'roadmap'! !

!GMStaticMap methodsFor: 'public' stamp: 'rs 7/25/2013 08:38'!
satelliteMap
	"Configure map to be shown as satellite image"
	
	self mapType: 'satellite'! !

!GMStaticMap methodsFor: 'accessing' stamp: 'rs 7/25/2013 08:50'!
scale
	^ scale! !

!GMStaticMap methodsFor: 'accessing' stamp: 'rs 7/25/2013 08:50'!
scale: anObject
	scale := anObject! !

!GMStaticMap methodsFor: 'public' stamp: 'rs 7/25/2013 08:38'!
terrainMap
	"Configure map to be shown with terrain info"
	
	self mapType: 'terrain'! !

!GMStaticMap methodsFor: 'public' stamp: 'RichardStern 12/31/2010 12:50'!
useMobileDeviceMap
	"Configure receiver to show map optimized for mobile output devices"
	
	self mobile: true.! !

!GMStaticMap methodsFor: 'private-image attributes' stamp: 'rs 7/25/2013 08:48'!
width
	"Return the width of the map - which is a property inherited from image tag"
	"Means that map is always as big as the image tag itself - though they could have
	different extents in theory. So not fully consitent, but same size is usually the intention"	

	^self attributes at: 'width' ifAbsent: [nil].
! !

!GMStaticMap methodsFor: 'accessing' stamp: 'rs 12/23/2008 16:19'!
zoom
	^ zoom! !

!GMStaticMap methodsFor: 'accessing' stamp: 'rs 12/23/2008 16:19'!
zoom: anObject
	zoom := anObject! !

WAComponent subclass: #GMStaticMapExample
	instanceVariableNames: 'longitude latitude width height scale zoom imageFormat markers mapType'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GoogleStaticMap-Examples'!

!GMStaticMapExample methodsFor: 'private' stamp: 'RichardStern 12/6/2010 14:54'!
centerOnMapPoint: aGMMapPoint
	
	self 
		longitude: aGMMapPoint longitude;
		latitude: aGMMapPoint latitude.! !

!GMStaticMapExample methodsFor: 'accessing' stamp: 'rs 1/21/2010 12:56'!
height
	^ height! !

!GMStaticMapExample methodsFor: 'accessing' stamp: 'rs 1/21/2010 12:57'!
height: anObject
	height := anObject! !

!GMStaticMapExample methodsFor: 'accessing' stamp: 'rs 3/29/2010 16:07'!
imageFormat
	^ imageFormat! !

!GMStaticMapExample methodsFor: 'accessing' stamp: 'rs 3/29/2010 16:07'!
imageFormat: anObject
	imageFormat := anObject! !

!GMStaticMapExample methodsFor: 'initializing' stamp: 'rs 1/21/2010 13:28'!
initialize
	super initialize.				
	
	markers := OrderedCollection new.					
	self setInitialParameters.
! !

!GMStaticMapExample methodsFor: 'accessing' stamp: 'rs 1/21/2010 12:57'!
latitude
	^ latitude! !

!GMStaticMapExample methodsFor: 'accessing' stamp: 'rs 1/21/2010 12:57'!
latitude: anObject
	latitude := anObject! !

!GMStaticMapExample methodsFor: 'accessing' stamp: 'rs 1/21/2010 12:57'!
longitude
	^ longitude! !

!GMStaticMapExample methodsFor: 'accessing' stamp: 'rs 1/21/2010 12:57'!
longitude: anObject
	longitude := anObject! !

!GMStaticMapExample methodsFor: 'accessing' stamp: 'rs 7/25/2013 08:40'!
mapType
	^ mapType! !

!GMStaticMapExample methodsFor: 'accessing' stamp: 'rs 7/25/2013 08:40'!
mapType: anObject
	mapType := anObject! !

!GMStaticMapExample methodsFor: 'accessing' stamp: 'rs 1/21/2010 13:23'!
markers
	^markers! !

!GMStaticMapExample methodsFor: 'accessing' stamp: 'rs 1/21/2010 13:24'!
markers: anObject
	markers := anObject! !

!GMStaticMapExample methodsFor: 'actions' stamp: 'rs 1/21/2010 13:26'!
removeAllMarkers
	markers := OrderedCollection new.! !

!GMStaticMapExample methodsFor: 'actions' stamp: 'RichardStern 1/3/2011 15:47'!
removeAllMarkersSatisfying: aBlock

	self markers: (self markers reject: aBlock).! !

!GMStaticMapExample methodsFor: 'rendering' stamp: 'RichardStern 12/6/2010 11:20'!
renderContentOn: html

	"Render innput form with receivers parameters and the resulting map"
	html div
		class: 'inputForm';
		with: [ self renderFormsOn: html].	
	html div
		class: 'map';
		with: [ self renderMapOn: html].
		! !

!GMStaticMapExample methodsFor: 'rendering' stamp: 'rs 1/21/2010 13:21'!
renderFormsOn: html

	self renderMapFormOn: html.
	html break.
! !

!GMStaticMapExample methodsFor: 'rendering-map form' stamp: 'rs 3/29/2010 16:06'!
renderImageFormatSelectionOn: html
	"Render dropdown box allowing to choose map image format"
	
	html tableRow:
	[
		html tableData:
		[
			html label 
				for: #imageFormat;
				with: 'Image format'.
		].
	
		html tableData:
		[
			html text: '-'. 
		].

		html tableData:
		[		
			html select
            list: (GMStaticMap supportedImageFormats);
				selected: self imageFormat;
            on: #imageFormat of: self.

		].
	].! !

!GMStaticMapExample methodsFor: 'rendering' stamp: 'rs 3/29/2010 14:43'!
renderInputCaption: aString on: html

	html tableData
		class: 'caption';
		with:
		[
			html text: aString.
		].
! !

!GMStaticMapExample methodsFor: 'rendering' stamp: 'rs 3/29/2010 14:43'!
renderInputCaptionsOn: html

		html tableHead:
		[
			self 
				renderInputCaption: 'Parameter' on: html;
				renderInputCaption: 'Hint' on: html;
				renderInputCaption: 'Value' on: html.																					
		].
			
! !

!GMStaticMapExample methodsFor: 'rendering' stamp: 'rs 3/30/2010 09:37'!
renderInputFor: aSymbol label: aLabelString hint: aHintString model: aModel on: html
	"Utility method used to render all the input fields in example in unified way"

	html tableRow:
	[
		html tableData:
		[
			html label 
				for: aSymbol;
				with: aLabelString.
		].
	
		html tableData:
		[
			html text: aHintString. 
		].

		html tableData:
		[		
			html textInput 
				size: 18;
				on: aSymbol of: aModel.
		].
	].! !

!GMStaticMapExample methodsFor: 'rendering-map form' stamp: 'rs 7/29/2013 08:16'!
renderMapFormOn: html
	"Render a form allowing ot change basic map parameters"
	
	html heading
			level: 5;
			with: 'Map'.

	html form
		with:
		[			
			html table:
			[
				self renderInputCaptionsOn: html.
			
				self 
					renderMapInputFor: #longitude label: 'Longitude' hint: '-' on: html;
					renderMapInputFor: #latitude label: 'Latitude' hint: '-' on: html;				
					renderMapInputFor: #zoom label: 'Zoom' hint: '0 - 19' on: html;
					renderMapInputFor: #width label: 'Map width' hint: 'max 640' on: html;
					renderMapInputFor: #height label: 'Map height' hint: 'max 640' on: html;
					renderMapTypeSelectionOn: html;
					renderMapScaleSelectionOn: html;
					renderImageFormatSelectionOn: html.
			].		
					
			html cancelButton 
					value: 'Reset';
					callback: [self resetMap].
			html submitButton 
					value: 'Update'.						
			html submitButton 
					value: 'Zoom in';
					callback: [self zoomIn].
			html submitButton 
					value: 'Zoom out';
					callback: [self zoomOut].											
		].
		
! !

!GMStaticMapExample methodsFor: 'rendering-map form' stamp: 'rs 3/29/2010 14:39'!
renderMapInputFor: aSymbol label: aLabelString hint: aHintString on: html
	"Utility method used to render all the input fields in example in unified way"
	
	self 
		renderInputFor: aSymbol 
		label: aLabelString 
		hint: aHintString 
		model: self
		on: html! !

!GMStaticMapExample methodsFor: 'rendering' stamp: 'rs 7/29/2013 08:10'!
renderMapOn: html

	^html googleStaticMap
		longitude: self longitude asNumber;
		latitude: self latitude asNumber;
		zoom: self zoom asNumber;
		width: self width asNumber;
		height: self height asNumber;
		mapType: self mapType asString;
		scale: self scale asNumber;
		imageFormat: self imageFormat;
		addMarkerGroups: self markers;
		yourself.

! !

!GMStaticMapExample methodsFor: 'rendering-map form' stamp: 'rs 7/29/2013 08:16'!
renderMapScaleSelectionOn: html
	"Render checkbox allowing to choose scale value for map (usually needed 
	 for mobile devices)"
	
	html tableRow:
	[
		html tableData:
		[
			html label 
				for: #scale;
				with: 'Scale'.
		].
	
		html tableData:
		[
			html text: '4 only for enterprise use'. 
		].

		html tableData:
		[		
			html select
				list: GMStaticMap supportedScaleValues;
				selected: self scale;
		            on: #scale of: self.
		].
	].! !

!GMStaticMapExample methodsFor: 'rendering-map form' stamp: 'rs 7/25/2013 08:41'!
renderMapTypeSelectionOn: html
	"Render dropdown box allowing to choose map type"
	
	html tableRow:
	[
		html tableData:
		[
			html label 
				for: #mapType;
				with: 'Map type'.
		].
	
		html tableData:
		[
			html text: '-'. 
		].

		html tableData:
		[		
			html select
		            list: (GMStaticMap supportedMapTypes);
				selected: self mapType;
		            on: #mapType of: self.
		].
	].! !

!GMStaticMapExample methodsFor: 'actions' stamp: 'rs 1/21/2010 13:27'!
resetMap
	self 
		setInitialParameters;
		removeAllMarkers.

! !

!GMStaticMapExample methodsFor: 'accessing' stamp: 'rs 7/29/2013 08:13'!
scale
	^ scale! !

!GMStaticMapExample methodsFor: 'accessing' stamp: 'rs 7/29/2013 08:13'!
scale: anObject
	scale := anObject! !

!GMStaticMapExample methodsFor: 'private' stamp: 'rs 7/29/2013 08:13'!
setInitialParameters
	
	longitude := '16.3725'.
	latitude := '48.2085'.
	zoom := '5'.
	width := '640'.
	height := '640'.
	mapType := 'roadmap'.
	scale := 1.
! !

!GMStaticMapExample methodsFor: 'rendering' stamp: 'rs 1/21/2010 13:07'!
style

^'
div.inputForm {float: left; margin-right: 20px;}
div.map {flow: right;}
div.map img {vertical-align: middle;}
div.inputForm table { border: 1px solid gray; background-color: #e0e0e0; margin-bottom: 10px}
div.inputForm td {padding-left: 5px; padding-right: 15px; font-size:0.8em;}
td.caption {font-weight: bold; background-color: #c0c0c0}
'.

		! !

!GMStaticMapExample methodsFor: 'accessing' stamp: 'rs 1/21/2010 12:57'!
width
	^ width! !

!GMStaticMapExample methodsFor: 'accessing' stamp: 'rs 1/21/2010 12:58'!
width: anObject
	width := anObject! !

!GMStaticMapExample methodsFor: 'accessing' stamp: 'rs 1/21/2010 12:58'!
zoom
	^ zoom! !

!GMStaticMapExample methodsFor: 'accessing' stamp: 'rs 1/21/2010 12:58'!
zoom: anObject
	zoom := anObject! !

!GMStaticMapExample methodsFor: 'actions' stamp: 'rs 1/21/2010 13:07'!
zoomIn
	| zoomLevel |
	
	zoomLevel := self zoom asInteger.
	zoomLevel := ((zoomLevel + 1) min: 19) max: 0.
	
	self zoom: zoomLevel asString.! !

!GMStaticMapExample methodsFor: 'actions' stamp: 'rs 1/21/2010 13:07'!
zoomOut
	| zoomLevel |
	
	zoomLevel := self zoom asInteger.
	zoomLevel := ((zoomLevel - 1) max: 0) min: 19.
	
	self zoom: zoomLevel asString.! !

GMStaticMapExample subclass: #GMStaticMapExampleAddressSearch
	instanceVariableNames: 'address outputFormat searchResult'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GoogleStaticMap-Examples'!

!GMStaticMapExampleAddressSearch class methodsFor: 'examples' stamp: 'rs 1/21/2010 13:51'!
example

	^self new! !

!GMStaticMapExampleAddressSearch methodsFor: 'accessing' stamp: 'rs 1/21/2010 13:02'!
address
	^ address! !

!GMStaticMapExampleAddressSearch methodsFor: 'accessing' stamp: 'rs 1/21/2010 13:02'!
address: anObject
	address := anObject! !

!GMStaticMapExampleAddressSearch methodsFor: 'accessing' stamp: 'rs 3/30/2010 09:26'!
outputFormat
	^ outputFormat! !

!GMStaticMapExampleAddressSearch methodsFor: 'accessing' stamp: 'rs 3/30/2010 09:26'!
outputFormat: anObject
	outputFormat := anObject! !

!GMStaticMapExampleAddressSearch methodsFor: 'rendering' stamp: 'rs 3/30/2010 09:38'!
renderAddressFormOn: html

	html heading
			level: 5;
			with: 'Address search'.

	html form:
	[
		html table:
		[
			self renderInputCaptionsOn: html.
			
			self 
				renderInputFor: #address
				label: 'Address' 
				hint: 'Search string'
				model: self
				on: html.
	

			self renderOutputFormatSelectionOn: html.
		].		

		html submitButton 
				value: 'Search';
				callback: [self searchAddress].				

	].
		
! !

!GMStaticMapExampleAddressSearch methodsFor: 'rendering' stamp: 'rs 3/30/2010 09:44'!
renderFormsOn: html

	self renderAddressFormOn: html.
	html break.
	self renderSearchResultOn: html.
	html break.
	self renderSearchResultMarkersOn: html! !

!GMStaticMapExampleAddressSearch methodsFor: 'rendering' stamp: 'rs 3/30/2010 09:45'!
renderOutputFormatSelectionOn: html
	"Render dropdown box allowing to choose output format of address search"
	
	html tableRow:
	[
		html tableData:
		[
			html label 
				for: #outputFormat;
				with: 'Output format'.
		].
	
		html tableData:
		[
			html text: '-'. 
		].

		html tableData:
		[		
			html select
            list: (GMGeocodeRequest supportedOutputFormats);
				selected: self outputFormat;
            on: #outputFormat of: self.

		].
	].! !

!GMStaticMapExampleAddressSearch methodsFor: 'rendering' stamp: 'RichardStern 12/6/2010 14:57'!
renderResultLineFor: aGMStaticMapMarker on: html

	html tableRow:
	[
		html 
			tableData: aGMStaticMapMarker label asString;
			tableData: aGMStaticMapMarker points first longitude asString;
			tableData: aGMStaticMapMarker points first latitude asString
	].! !

!GMStaticMapExampleAddressSearch methodsFor: 'rendering' stamp: 'rs 3/30/2010 09:34'!
renderSearchResultMarkersOn: html
	"Search result is given in form a markers for sake of simplcity. Render them here if any present"

	self markers isEmpty ifFalse:
	[
		html heading
				level: 5;
				with: 'Found locations'.
				
		html table:
		[
			self markers do:
			[:m |
				self renderResultLineFor: m on: html.
			].
		].
	]! !

!GMStaticMapExampleAddressSearch methodsFor: 'rendering' stamp: 'rs 3/30/2010 09:44'!
renderSearchResultOn: html
	"Search result is given in form a markers for sake of simplcityio. Render them here if any present"

	self markers isEmpty ifFalse:
	[
		html heading
				level: 5;
				with: 'Search result'.

		html break.		
		html teletype: self searchResult.
	]! !

!GMStaticMapExampleAddressSearch methodsFor: 'actions' stamp: 'RichardStern 12/6/2010 15:00'!
searchAddress

	"Get search result as text for output in example"
	self searchResult:(GMGeocodeRequest new
									address: self address;
									outputFormat: self outputFormat;
									resultString).	

	"Execute search again to get markers from result"
	self removeAllMarkers.
	self markers addAll: (GMGeocodeRequest new
									address: self address;
									resultMarkers).

	self markers isEmpty ifFalse:
	[	
		self centerOnMapPoint: self markers first firstPoint.
	].! !

!GMStaticMapExampleAddressSearch methodsFor: 'accessing' stamp: 'rs 3/30/2010 09:26'!
searchResult
	^ searchResult! !

!GMStaticMapExampleAddressSearch methodsFor: 'accessing' stamp: 'rs 3/30/2010 09:26'!
searchResult: anObject
	searchResult := anObject! !

!GMStaticMapExampleAddressSearch methodsFor: 'private' stamp: 'RichardStern 7/25/2010 09:50'!
setInitialParameters
	
	super setInitialParameters.

	self 
		address: String new;
		searchResult: String new;
		outputFormat: 'csv';
		zoom: '16'.! !

GMStaticMapExample subclass: #GMStaticMapExampleMarkers
	instanceVariableNames: 'standardMarker customMarker'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GoogleStaticMap-Examples'!

!GMStaticMapExampleMarkers class methodsFor: 'examples' stamp: 'rs 1/21/2010 13:51'!
example

	^self new! !

!GMStaticMapExampleMarkers methodsFor: 'actions' stamp: 'RichardStern 1/3/2011 15:22'!
addCustomMarker

	self 
		addMarker: self customMarker;
		resetCustomMarker.
	! !

!GMStaticMapExampleMarkers methodsFor: 'actions' stamp: 'RichardStern 1/3/2011 15:55'!
addMarker: aGMMarkerGroup

	self markers add: aGMMarkerGroup.
	self centerOnMapPoint: aGMMarkerGroup points first.

	! !

!GMStaticMapExampleMarkers methodsFor: 'actions' stamp: 'RichardStern 1/3/2011 15:22'!
addStandardMarker
	self 
		addMarker: self standardMarker;
		resetStandardMarker.! !

!GMStaticMapExampleMarkers methodsFor: 'accessing' stamp: 'RichardStern 1/3/2011 15:18'!
customMarker
	^ customMarker! !

!GMStaticMapExampleMarkers methodsFor: 'accessing' stamp: 'RichardStern 1/3/2011 15:18'!
customMarker: anObject
	customMarker := anObject! !

!GMStaticMapExampleMarkers methodsFor: 'actions' stamp: 'RichardStern 1/3/2011 15:45'!
removeAllCustomMarkers
	self removeAllMarkersSatisfying: [:m | m isKindOf: GMStaticMapIconMarkerGroup]! !

!GMStaticMapExampleMarkers methodsFor: 'actions' stamp: 'RichardStern 1/3/2011 15:32'!
removeAllStandardMarkers
	self removeAllMarkersSatisfying: [:m | m isKindOf: GMStaticMapStandardMarkerGroup]! !

!GMStaticMapExampleMarkers methodsFor: 'rendering' stamp: 'RichardStern 1/3/2011 15:42'!
renderCustomMarkerFormOn: html

	html heading
			level: 5;
			with: 'Custom Markers'.

	html form:
	[
		html table:
		[
			self renderInputCaptionsOn: html.
			
			self 
				renderInputFor: #longitude label: 'Longitude' hint: '-' model: self standardMarker firstPoint on: html;
				renderInputFor: #latitude label: 'Latitude' hint: '-' model: self standardMarker firstPoint on: html;					
				renderInputFor: #icon label: 'Icon' hint: 'Url of marker icon' model: self customMarker on: html;
				renderCustomMarkerShadowSelectionOn: html.
		].
	
		html cancelButton 
				value: 'Remove all custom markers';
				callback: [self removeAllCustomMarkers].
		html submitButton 
				value: 'Add custom marker';
				callback: [self addCustomMarker].				

	].
		! !

!GMStaticMapExampleMarkers methodsFor: 'rendering' stamp: 'RichardStern 1/3/2011 16:04'!
renderCustomMarkerShadowSelectionOn: html
	"Render checkbox allowing to choose if custom marker should have shadow"
	
	html tableRow:
	[
		html tableData:
		[
			html label 
				for: #shadow;
				with: 'Shadow'.
		].
	
		html tableData:
		[
			html text: 'Affects used center!!'. 
		].

		html tableData:
		[		
			html checkbox
		            on: #shadow of: self customMarker.
		].
	].! !

!GMStaticMapExampleMarkers methodsFor: 'rendering' stamp: 'RichardStern 1/3/2011 15:48'!
renderFormsOn: html

	self renderMapFormOn: html.
	html break.
	self renderStandardMarkerFormOn: html.
	html break.
	self renderCustomMarkerFormOn: html.
	html break.! !

!GMStaticMapExampleMarkers methodsFor: 'rendering' stamp: 'RichardStern 1/3/2011 15:34'!
renderStandardMarkerColorSelectionOn: html
	"Render out a drop down allowing to select marker color"
	
	html tableRow:
	[
		html tableData:
		[
			html label 
				for: #color;
				with: 'Color'.
		].
	
		html tableData:
		[
			html text: '-'. 
		].

		html tableData:
		[		
			html select
          			list: (GMStaticMapStandardMarkerGroup supportedColors);
				selected: self standardMarker color;
		            on: #color of: self standardMarker.
		].
	].! !

!GMStaticMapExampleMarkers methodsFor: 'rendering' stamp: 'RichardStern 1/3/2011 15:30'!
renderStandardMarkerFormOn: html

	html heading
			level: 5;
			with: 'Standard markers'.

	html form:
	[
		html table:
		[
			self renderInputCaptionsOn: html.
			
			self 
				renderInputFor: #longitude label: 'Longitude' hint: '-' model: self standardMarker firstPoint on: html;
				renderInputFor: #latitude label: 'Latitude' hint: '-' model: self standardMarker firstPoint on: html;				
				renderInputFor: #label label: 'Label' hint: 'single char' model: self standardMarker on: html;
				renderStandardMarkerColorSelectionOn: html;
				renderStandardMarkerSizeSelectionOn: html.
		].
	
		html cancelButton 
				value: 'Remove all standard markers';
				callback: [self removeAllStandardMarkers].
		html submitButton 
				value: 'Add marker';
				callback: [self addStandardMarker].				

	].
		! !

!GMStaticMapExampleMarkers methodsFor: 'rendering' stamp: 'RichardStern 1/3/2011 15:34'!
renderStandardMarkerSizeSelectionOn: html
	"Render out a drop down allowing to select marker size"
	
	html tableRow:
	[
		html tableData:
		[
			html label 
				for: #color;
				with: 'Size'.
		].
	
		html tableData:
		[
			html text: '-'. 
		].

		html tableData:
		[		
			html select
		            list: (GMStaticMapStandardMarkerGroup supportedSizes);
				selected: self standardMarker size;
		            on: #size of: self standardMarker.
		].
	].! !

!GMStaticMapExampleMarkers methodsFor: 'private' stamp: 'RichardStern 1/3/2011 16:15'!
resetCustomMarker
	self customMarker: GMStaticMapIconMarkerGroup new.
	self customMarker
			icon: 'http://chart.apis.google.com/chart?chst=d_map_pin_icon&chld=cafe';
			shadow: true;
			addPointWithLongitude: (self longitude) andLatitude: (self latitude).! !

!GMStaticMapExampleMarkers methodsFor: 'private' stamp: 'RichardStern 1/3/2011 16:15'!
resetStandardMarker
	self standardMarker: GMStaticMapStandardMarkerGroup new.	
	self standardMarker 
			color: 'red';
			label: (self markers size+1) asString;
			addPointWithLongitude: (self longitude) andLatitude: (self latitude).! !

!GMStaticMapExampleMarkers methodsFor: 'private' stamp: 'RichardStern 1/3/2011 15:40'!
setInitialParameters
	
	super setInitialParameters.
	self 
		resetStandardMarker;
		resetCustomMarker.
! !

!GMStaticMapExampleMarkers methodsFor: 'accessing' stamp: 'RichardStern 1/3/2011 15:20'!
standardMarker
	^standardMarker! !

!GMStaticMapExampleMarkers methodsFor: 'accessing' stamp: 'RichardStern 1/3/2011 15:20'!
standardMarker: anObject
	standardMarker := anObject! !

GMStaticMapExample subclass: #GMStaticMapExamplePath
	instanceVariableNames: 'path pathPoints selectedPathPoints pathPointLongitude pathPointLatitude'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GoogleStaticMap-Examples'!

!GMStaticMapExamplePath class methodsFor: 'examples' stamp: 'rs 1/21/2010 13:51'!
example

	^self new! !

!GMStaticMapExamplePath methodsFor: 'actions' stamp: 'rs 1/21/2010 15:27'!
addPathPoint

	self pathPoints add:
				(GMStaticMapPoint new
					longitude: (self pathPointLongitude asString);
					latitude: (self pathPointLatitude asString);
					yourself).! !

!GMStaticMapExamplePath methodsFor: 'initializing' stamp: 'rs 1/21/2010 15:25'!
initialize
	super initialize.
	pathPoints  := OrderedCollection new.
	selectedPathPoints  := OrderedCollection new.! !

!GMStaticMapExamplePath methodsFor: 'accessing' stamp: 'rs 1/21/2010 13:01'!
path
	^ path! !

!GMStaticMapExamplePath methodsFor: 'accessing' stamp: 'rs 1/21/2010 13:01'!
path: anObject
	path := anObject! !

!GMStaticMapExamplePath methodsFor: 'accessing' stamp: 'rs 1/21/2010 15:01'!
pathPointLatitude
	^ pathPointLatitude! !

!GMStaticMapExamplePath methodsFor: 'accessing' stamp: 'rs 1/21/2010 15:01'!
pathPointLatitude: anObject
	pathPointLatitude := anObject! !

!GMStaticMapExamplePath methodsFor: 'accessing' stamp: 'rs 1/21/2010 15:01'!
pathPointLongitude
	^ pathPointLongitude! !

!GMStaticMapExamplePath methodsFor: 'accessing' stamp: 'rs 1/21/2010 15:01'!
pathPointLongitude: anObject
	pathPointLongitude := anObject! !

!GMStaticMapExamplePath methodsFor: 'accessing' stamp: 'rs 1/21/2010 15:25'!
pathPoints
	^ pathPoints! !

!GMStaticMapExamplePath methodsFor: 'accessing' stamp: 'rs 1/21/2010 15:25'!
pathPoints: anObject
	pathPoints := anObject! !

!GMStaticMapExamplePath methodsFor: 'rendering' stamp: 'rs 1/21/2010 15:12'!
renderFormsOn: html

	self renderMapFormOn: html.
	html break.	
	self renderPathFormOn: html.
	html break.
	self renderPathPointsFormOn: html.! !

!GMStaticMapExamplePath methodsFor: 'rendering' stamp: 'RichardStern 12/6/2010 14:27'!
renderMapOn: html

	^(super renderMapOn: html)
			addMarkerGroups: self markers;
			path: self path;
			yourself.
! !

!GMStaticMapExamplePath methodsFor: 'rendering' stamp: 'RichardStern 12/6/2010 12:07'!
renderPathFormOn: html

	html heading
			level: 5;
			with: 'Path'.

	html form:
	[
		html table:
		[
			self renderInputCaptionsOn: html.

			self 
				renderPathInputFor: #color 
				label: 'Color' 
				hint: 'RBG color value' 
				on: html.
			self 
				renderPathInputFor: #fillcolor 
				label: 'Fill color' 
				hint: 'RBG color value' 
				on: html.
			self 
				renderPathInputFor: #weight 
				label: 'Line width' 
				hint: 'in Pixels' 
				on: html.
										
			html tableRow:
			[
				html tableData:
				[
					html label with: 'Paths points'.
				].
	
				html tableData: [html text: 'GPS Points'; break; text: '(select here, enter below)'].

				html tableData:
				[		
					html multiSelect
						size: 3;
						list: self pathPoints;
						labels: [:p | p displayString];
						selected: self selectedPathPoints;
						callback: [ :value | self selectedPathPoints: value].
				].
			].		

		].
	
		html cancelButton 
				value: 'Reset';
				callback: [self resetMap].
					
		html submitButton 
				value: 'Show path';
				callback: [self showPath].				

	].
		
! !

!GMStaticMapExamplePath methodsFor: 'rendering' stamp: 'rs 1/21/2010 13:20'!
renderPathInputFor: aSymbol label: aLabelString hint: aHintString on: html

	self 
		renderInputFor: aSymbol 
		label: aLabelString 
		hint: aHintString 
		model: self path
		on: html
! !

!GMStaticMapExamplePath methodsFor: 'rendering' stamp: 'rs 1/21/2010 15:29'!
renderPathPointsFormOn: html

	html heading
			level: 5;
			with: 'Path points'.

	html form:
	[
		html table:
		[
			self 
				renderMapInputFor: #pathPointLongitude label: 'Longitude' hint: '-' on: html;
				renderMapInputFor: #pathPointLatitude label: 'Latitude' hint: '-' on: html.	
		].

		html submitButton 
			value: 'Add point ';
			callback: [self addPathPoint].	

	].
		
! !

!GMStaticMapExamplePath methodsFor: 'actions' stamp: 'RichardStern 12/6/2010 12:55'!
resetPath
	path := GMStaticMapPath new.	
	self path
			color: '0xff0000ff';
			fillcolor: '0x0000ff';
			weight: '3'.
				
	self 
		pathPoints: OrderedCollection new;
		selectedPathPoints: OrderedCollection new.
		! !

!GMStaticMapExamplePath methodsFor: 'accessing' stamp: 'rs 1/21/2010 15:04'!
selectedPathPoints
	^ selectedPathPoints! !

!GMStaticMapExamplePath methodsFor: 'accessing' stamp: 'rs 1/21/2010 15:04'!
selectedPathPoints: anObject
	selectedPathPoints := anObject! !

!GMStaticMapExamplePath methodsFor: 'private' stamp: 'rs 3/29/2010 14:57'!
setInitialParameters
	
	super setInitialParameters.
	self resetPath.
						
	self pathPointLongitude: self longitude.
	self pathPointLatitude: self latitude.

! !

!GMStaticMapExamplePath methodsFor: 'actions' stamp: 'rs 3/29/2010 15:38'!
showPath

	self selectedPathPoints isEmpty ifTrue:
	[
		^self inform: 'No path points selected!!'.
	].
	
	self path resetPoints.
	self selectedPathPoints do: [:m | self path addPoint: m].
			! !

GMStaticMapExample subclass: #GMStaticMapExamplePlainMap
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GoogleStaticMap-Examples'!

!GMStaticMapExamplePlainMap class methodsFor: 'examples' stamp: 'rs 1/21/2010 13:53'!
example

	^self new! !

WAComponent subclass: #GMStaticOverallExample
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GoogleStaticMap-Examples'!

!GMStaticOverallExample class methodsFor: 'examples' stamp: 'rs 3/29/2010 14:59'!
example

	^self new! !

!GMStaticOverallExample methodsFor: 'private' stamp: 'RichardStern 1/3/2011 15:32'!
majorMarkersOnZeroMeridian

	| group |
	
	group := GMStaticMapStandardMarkerGroup  new
							color: 'orange';
							size: 'small';
							yourself.			
		
	30 to: 60 by: 5 do:
	[:i | 
		group addPointWithLongitude: 0 andLatitude: i.
	].

	^group.! !

!GMStaticOverallExample methodsFor: 'private' stamp: 'RichardStern 12/6/2010 13:51'!
mappointBetweenParisAndRome
	^GMStaticMapPoint new
			longitude: 11;
			latitude: 47;
			yourself.

	
! !

!GMStaticOverallExample methodsFor: 'private' stamp: 'rs 3/29/2010 15:28'!
mappointBetweenViennaAndParis
	^GMStaticMapPoint new
			longitude: 7;
			latitude: 51;
			yourself.

	
! !

!GMStaticOverallExample methodsFor: 'private' stamp: 'RichardStern 1/3/2011 15:32'!
markerForParis
	^GMStaticMapStandardMarkerGroup  new
			addPointWithLongitude: 2.3 andLatitude: 48.8;	
			label: 'P';
			color: 'yellow';
			size: 'normal';
			yourself.

	
! !

!GMStaticOverallExample methodsFor: 'private' stamp: 'RichardStern 1/3/2011 15:32'!
markerForRome
	^GMStaticMapStandardMarkerGroup  new
			addPointWithLongitude: 12.50 andLatitude: 41.88;
			label: 'R';
			color: 'green';
			size: 'normal';
			yourself.

	
! !

!GMStaticOverallExample methodsFor: 'private' stamp: 'RichardStern 1/3/2011 15:32'!
markerForVienna
	^GMStaticMapStandardMarkerGroup  new
			addPointWithLongitude: 16.3725 andLatitude: 48.2085;
			label: 'V';
			color: 'blue';
			size: 'normal';
			yourself.

	
! !

!GMStaticOverallExample methodsFor: 'private' stamp: 'RichardStern 12/6/2010 14:48'!
markerGroups
	^OrderedCollection new
			add: self markerForVienna;
			add: self markerForParis;
			add: self markerForRome;
			add: self majorMarkersOnZeroMeridian;
			add: self minorMarkersOnZeroMeridian;			
			yourself.
	
! !

!GMStaticOverallExample methodsFor: 'private' stamp: 'RichardStern 1/3/2011 15:32'!
minorMarkersOnZeroMeridian

	| group |
	
	group := GMStaticMapStandardMarkerGroup  new
							color: 'green';
							size: 'tiny';
							yourself.

	31 to: 59 do:
	[:i | 
		group addPointWithLongitude: 0 andLatitude: i.
	].


	^group.! !

!GMStaticOverallExample methodsFor: 'private' stamp: 'RichardStern 12/6/2010 14:45'!
path
	^GMStaticMapPath new
				color: 'red';
				fillcolor: 'brown';
				weight: 4;
				points: self pathPoints;
				yourself.! !

!GMStaticOverallExample methodsFor: 'private' stamp: 'RichardStern 12/6/2010 15:19'!
pathPoints
	^OrderedCollection new
			add: self markerForVienna firstPoint;
			add: self mappointBetweenViennaAndParis;
			add: self markerForParis firstPoint;
			add: self mappointBetweenParisAndRome;
			add: self markerForRome firstPoint;
			add: self markerForVienna firstPoint;
			yourself.
	
! !

!GMStaticOverallExample methodsFor: 'rendering' stamp: 'rs 7/25/2013 09:04'!
renderContentOn: html

	html googleStaticMap
		longitude: 10;
		latitude: 48;
		zoom: 5;
		width: 640;
		height: 640;
		roadMap;
		addMarkerGroups: self markerGroups;
		path: self path.
		! !

!WAHtmlCanvas methodsFor: '*GoogleStaticMap' stamp: 'rs 12/26/2008 09:55'!
googleStaticMap

	^self brush: GMStaticMap new! !

Object subclass: #GMApiKey
	instanceVariableNames: 'apiKey'
	classVariableNames: 'Singleton'
	poolDictionaries: ''
	category: 'GoogleStaticMap'!

!GMApiKey commentStamp: '<historical>' prior: 0!
GMApiKey is a singleton to store the API key for Google maps. With version 2 of google static maps api, it is not required any more - but the class was kept for the case that a key is still used.

!

!GMApiKey class methodsFor: 'accessing' stamp: 'rs 12/26/2008 09:31'!
current
	"Return existing singleton instance. Create one if not yet present"
	
	Singleton isNil ifTrue: 
	[
		Singleton := self new
							apiKey: self defaultKey;
							yourself.
	].
	^Singleton.! !

!GMApiKey class methodsFor: 'accessing' stamp: 'rs 12/26/2008 09:30'!
defaultKey
	"Return google api key to use by default"
	
	^'Please enter your key here'.
! !

!GMApiKey class methodsFor: 'accessing' stamp: 'rs 12/26/2008 09:32'!
reset
	
	Singleton := nil.! !

!GMApiKey methodsFor: 'private' stamp: 'RichardStern 7/25/2010 09:53'!
addYourselfToUrl: aWAUrl
	"Add receiver as parameter with name 'key' to passed URL"
	
	aWAUrl 
		addField: 'key' 
		value: self apiKey.! !

!GMApiKey methodsFor: 'accessing' stamp: 'rs 12/23/2008 15:24'!
apiKey
	^ apiKey! !

!GMApiKey methodsFor: 'accessing' stamp: 'rs 12/23/2008 15:24'!
apiKey: anObject
	apiKey := anObject! !

Object subclass: #GMGeocodeRequest
	instanceVariableNames: 'address outputFormat'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GoogleStaticMap'!

!GMGeocodeRequest commentStamp: '<historical>' prior: 0!
GMGeocodeRequest represents a single geocoding request against the static maps API. 

Instance Variables:
	address	<String>		The address fragment to search for
	outputFormat	<String> 	Desired format for result data - csv by default!

!GMGeocodeRequest class methodsFor: 'constants' stamp: 'rs 3/30/2010 09:31'!
supportedOutputFormats
	"Return a list of supported output formats for search result" 

	^#('xml' 'kml' 'csv' 'json')
! !

!GMGeocodeRequest methodsFor: 'accessing' stamp: 'rs 4/27/2009 13:20'!
address
	^ address! !

!GMGeocodeRequest methodsFor: 'accessing' stamp: 'rs 4/27/2009 13:22'!
address: anObject
	"set the address for whch to look up coordinates"
	address := anObject! !

!GMGeocodeRequest methodsFor: 'private' stamp: 'RichardStern 12/6/2010 11:11'!
assembleRequestUrl
	"Assemble URL of HTTP-Get-Request to GoogleMaps that receiver finally represents"

	^WAUrl new
		scheme: 'http';
		host: 'maps.google.com';
		addToPath: 'maps';
		addToPath: 'geo';
		addField: 'q' value: self address;
		addField: 'output' value: self outputFormat asString;
		asString.! !

!GMGeocodeRequest methodsFor: 'private' stamp: 'rs 3/29/2010 15:56'!
execute
	"Execute the address lookup. Return a stream with the result (as got from Google) in the
	configured output format"
	
	^HTTPClient httpGet: self assembleRequestUrl.! !

!GMGeocodeRequest methodsFor: 'initializing' stamp: 'rs 4/27/2009 13:22'!
initialize

	address := String new.
	outputFormat := #csv.! !

!GMGeocodeRequest methodsFor: 'accessing' stamp: 'rs 4/27/2009 13:21'!
outputFormat
	^ outputFormat! !

!GMGeocodeRequest methodsFor: 'accessing' stamp: 'rs 4/27/2009 13:21'!
outputFormat: anObject
	"Set output format - allowed values are #xml, #kml, #csv, #json"
	outputFormat := anObject! !

!GMGeocodeRequest methodsFor: 'public' stamp: 'RichardStern 1/3/2011 15:32'!
resultMarkers
	"Execute address search and create a marker for each of the result 
	entries (actually 34 markers at max that are named from 1 - 9 
	and A - Z). Return collection of these markers"

	| result |

	self outputFormat: #csv.
	result := OrderedCollection new.

	self resultString subStrings doWithIndex:
	[:line :i | | marker |
		marker := GMStaticMapStandardMarkerGroup newFromGeocodeCSVLine: line index: i.
		marker isNil ifFalse: [ result add: marker.].
	].

	^result.! !

!GMGeocodeRequest methodsFor: 'public' stamp: 'RichardStern 12/31/2010 12:46'!
resultStream
	"Execute receiver and return the result stream (as received from Google)"
	
	^self execute! !

!GMGeocodeRequest methodsFor: 'public' stamp: 'RichardStern 12/31/2010 12:46'!
resultString
	"Execute receiver and return original result as string"
	
	^self execute contents.! !

Object subclass: #GMStaticMapPoint
	instanceVariableNames: 'longitude latitude'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GoogleStaticMap'!

!GMStaticMapPoint commentStamp: '<historical>' prior: 0!
GMStaticMapPoint is a helper class that represents a single geocoordinate (longitude and latitude))

Instance Variables:
	longitude	<Float>
	llatitude: 	<Float>!

!GMStaticMapPoint methodsFor: 'private' stamp: 'rs 1/13/2010 09:19'!
asPointOnlyUrlParameterOn: aStream
	"Write only the URL-representation of receivers coordinate 
	information (and NOT anythink more) out on passed stream"
	
	aStream 
		nextPutAll: self latitude asString;
		nextPut: $,;
		nextPutAll: self longitude asString.! !

!GMStaticMapPoint methodsFor: 'private' stamp: 'rs 1/13/2010 09:18'!
asUrlParameterOn: aStream
	"Write out receivers representation in an URL-request to Google static 
	maps api on passed stream"
	
	^self asPointOnlyUrlParameterOn: aStream.! !

!GMStaticMapPoint methodsFor: 'public' stamp: 'rs 1/21/2010 15:28'!
displayString
	^self longitude asString,'/', self latitude asString.! !

!GMStaticMapPoint methodsFor: 'accessing' stamp: 'rs 1/12/2010 15:19'!
latitude
	^ latitude! !

!GMStaticMapPoint methodsFor: 'accessing' stamp: 'rs 1/12/2010 15:19'!
latitude: anObject
	latitude := anObject! !

!GMStaticMapPoint methodsFor: 'accessing' stamp: 'rs 1/12/2010 15:19'!
longitude
	^ longitude! !

!GMStaticMapPoint methodsFor: 'accessing' stamp: 'rs 1/12/2010 15:19'!
longitude: anObject
	longitude := anObject! !

Object subclass: #GMStaticMapPointGroup
	instanceVariableNames: 'points'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GoogleStaticMap'!

!GMStaticMapPointGroup commentStamp: '<historical>' prior: 0!
GMStaticMapPointGroup is the base class for collections of map points. It especially tkaes care of correctly representing coordinates in Google API URLs.

Instance Variables:
	points	<(SequenceableCollection of: GMStaticMapPoint)>!

GMStaticMapPointGroup subclass: #GMStaticMapIconMarkerGroup
	instanceVariableNames: 'icon shadow'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GoogleStaticMap'!

!GMStaticMapIconMarkerGroup commentStamp: '<historical>' prior: 0!
GMStaticMapIconMarkerGroup represent a set of markers on a static map that are displayed by a custom icon instead of the standard marker icon.

Instance Variables:
	icon	<String>		Url of the icon
	shadow	<Boolean>		Indicates if icon should have shadow added
		

!

!GMStaticMapIconMarkerGroup methodsFor: 'private' stamp: 'RichardStern 1/3/2011 16:02'!
asUrlParameterOn: aStream
	"Write out receivers representation in an URL-request to Google static 
	maps api on passed stream"

	self hasIcon ifTrue: 
	[	aStream 
			nextPutAll: 'icon:';
			nextPutAll: self icon asString.
	].
	self hasShadow ifFalse: 
	[	aStream 
			nextPut: $|;
			nextPutAll: 'shadow:false'.
	].
		
	super asUrlParameterOn: aStream.			
! !

!GMStaticMapIconMarkerGroup methodsFor: 'private' stamp: 'RichardStern 1/3/2011 15:05'!
hasIcon
	^(self icon~~nil) and: [self icon isEmpty not]! !

!GMStaticMapIconMarkerGroup methodsFor: 'private' stamp: 'RichardStern 1/3/2011 15:05'!
hasShadow
	^(self shadow~~nil) and: [self shadow]! !

!GMStaticMapIconMarkerGroup methodsFor: 'accessing' stamp: 'RichardStern 1/3/2011 15:32'!
icon
	^ icon! !

!GMStaticMapIconMarkerGroup methodsFor: 'accessing' stamp: 'RichardStern 1/3/2011 15:32'!
icon: anObject
	icon := anObject! !

!GMStaticMapIconMarkerGroup methodsFor: 'initialize-release' stamp: 'RichardStern 1/3/2011 15:35'!
initialize
	super initialize.
	
	icon := String new.
	shadow := true.

	! !

!GMStaticMapIconMarkerGroup methodsFor: 'accessing' stamp: 'RichardStern 1/3/2011 15:33'!
shadow
	^ shadow! !

!GMStaticMapIconMarkerGroup methodsFor: 'accessing' stamp: 'RichardStern 1/3/2011 15:33'!
shadow: anObject
	shadow := anObject! !

GMStaticMapPointGroup subclass: #GMStaticMapPath
	instanceVariableNames: 'color fillcolor weight'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GoogleStaticMap'!

!GMStaticMapPath commentStamp: '<historical>' prior: 0!
GMStaticMapPath represents a set of coordinate points displayed on a map as a polyline (path)

Instance Variables:
	color		<String>		HTTP color vlaue - stroke color of the line
	weight		<Integer>		The width of the line (in pixels)!

!GMStaticMapPath methodsFor: 'private' stamp: 'RichardStern 12/6/2010 14:45'!
addYourselfToUrl: aWAUrl
	"Add receiver as parameter with name URL representing a Google-Maps-API-Call"

	self hasPoints ifTrue:
	[	| stream |	

		stream := WriteStream on: String new.	

		self hasColor ifTrue:
		[	stream 
				nextPutAll: 'color:';
				nextPutAll: self color asString;
				nextPut: $|.
		].
		self hasFillcolor ifTrue:
		[	stream 
				nextPutAll: 'fillcolor:';
				nextPutAll: self fillcolor asString;
				nextPut: $|.
		].

		stream 
			nextPutAll: 'weight:';
			nextPutAll: self weightValue asString.

		super asUrlParameterOn: stream.
	
		aWAUrl addField: 'path' value: stream contents.
	].

! !

!GMStaticMapPath methodsFor: 'accessing' stamp: 'RichardStern 12/6/2010 11:43'!
color 	
	^color! !

!GMStaticMapPath methodsFor: 'accessing' stamp: 'RichardStern 12/6/2010 11:43'!
color: aString
	color := aString! !

!GMStaticMapPath methodsFor: 'accessing' stamp: 'RichardStern 12/6/2010 11:44'!
fillcolor
	^fillcolor! !

!GMStaticMapPath methodsFor: 'accessing' stamp: 'RichardStern 12/6/2010 11:44'!
fillcolor: aString
	fillcolor := aString! !

!GMStaticMapPath methodsFor: 'private' stamp: 'RichardStern 12/6/2010 11:46'!
hasColor
	^self color isString and: [self color isEmpty not].! !

!GMStaticMapPath methodsFor: 'private' stamp: 'RichardStern 12/6/2010 11:46'!
hasFillcolor
	^self fillcolor isString and: [self fillcolor isEmpty not].! !

!GMStaticMapPath methodsFor: 'accessing' stamp: 'rs 1/12/2010 15:04'!
weight
	^ weight! !

!GMStaticMapPath methodsFor: 'accessing' stamp: 'rs 1/12/2010 15:04'!
weight: anObject
	weight := anObject! !

!GMStaticMapPath methodsFor: 'private' stamp: 'rs 1/12/2010 16:46'!
weightValue
	^self weight isNil 
		ifTrue: [1]
		ifFalse: [self weight].! !

!GMStaticMapPointGroup class methodsFor: 'constants' stamp: 'RichardStern 12/6/2010 15:20'!
supportedColors
	"Return predefined color names supported for map paths"
	
	^#('black' 'brown' 'green' 'purple' 'yellow' 'blue' 'gray' 'orange' 'red' 'white')! !

!GMStaticMapPointGroup methodsFor: 'public' stamp: 'RichardStern 12/6/2010 14:40'!
addPoint: aGMStaticMapPoint

	^self points add: aGMStaticMapPoint.! !

!GMStaticMapPointGroup methodsFor: 'public' stamp: 'RichardStern 12/6/2010 14:41'!
addPointWithLongitude: aLongitudeFloat andLatitude: aLatitudeFloat

	^self addPoint: (GMStaticMapPoint new
						longitude: aLongitudeFloat;
						latitude: aLatitudeFloat;
						yourself).! !

!GMStaticMapPointGroup methodsFor: 'private' stamp: 'RichardStern 12/6/2010 15:13'!
asUrlParameterOn: aStream
	"Write out receivers representation in an URL-request to Google static 
	maps api on passed stream"
		
	self points do:
	[:p |
		aStream nextPut: $|.			
		p asUrlParameterOn: aStream.	
	].
! !

!GMStaticMapPointGroup methodsFor: 'public' stamp: 'RichardStern 12/6/2010 14:59'!
firstPoint
	^self points first! !

!GMStaticMapPointGroup methodsFor: 'private' stamp: 'RichardStern 12/6/2010 15:13'!
hasPoints
	^(self points~~nil) and: [self points isEmpty not]! !

!GMStaticMapPointGroup methodsFor: 'initialize-release' stamp: 'RichardStern 12/6/2010 14:38'!
initialize
	super initialize.
	
	points := OrderedCollection new.

	! !

!GMStaticMapPointGroup methodsFor: 'private' stamp: 'RichardStern 12/6/2010 15:13'!
noOfPoints
	^self points size.! !

!GMStaticMapPointGroup methodsFor: 'accessing' stamp: 'RichardStern 12/6/2010 14:39'!
points
	^ points! !

!GMStaticMapPointGroup methodsFor: 'accessing' stamp: 'RichardStern 12/6/2010 14:39'!
points: anObject
	points := anObject! !

!GMStaticMapPointGroup methodsFor: 'private' stamp: 'RichardStern 12/6/2010 15:13'!
resetPoints
	self points: (self points class new).! !

GMStaticMapPointGroup subclass: #GMStaticMapStandardMarkerGroup
	instanceVariableNames: 'color label size'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GoogleStaticMap'!

!GMStaticMapStandardMarkerGroup commentStamp: '<historical>' prior: 0!
GMStaticMapMarkerGroup represents a set of markers (coordinate points) on a static map that are displayed in equal fashion (same color, label and size)

Instance Variables:
	color	<String>	HTTP color vlaue - stroke color of the line
	label	<String>	Label of the marker (single character)
	size	<String>	String (enumeration) value declaring the size of the marker icon!

!GMStaticMapStandardMarkerGroup class methodsFor: 'instance creation' stamp: 'RichardStern 12/6/2010 13:55'!
newFromGeocodeCSVLine: aString index: anInteger
	"Assume passed string to represent one line of the result of an address lookup (geocoding) in CSV format. If valid, create a marker instance representing it - or return nil otherwhise. Passed integer is index of the line and causes character/color used for marker"

	| marker words colors|

	colors := self supportedColors.
	marker := nil.

	words := (aString subStrings: ',').
	(words first = '200') ifTrue:
	[	
		marker := self new.
		marker
			addPointWithLongitude: ((words at: 4) asNumber) andLatitude: ((words at: 3) asNumber);
			label: (Character digitValue: anInteger) asString;
			color: (colors at: (anInteger \\ colors size)+1)
	].
					
	^marker.! !

!GMStaticMapStandardMarkerGroup class methodsFor: 'constants' stamp: 'RichardStern 12/6/2010 13:19'!
supportedSizes
	"Return a list of markers sizes allowed for static maps" 

	^#('normal' 'mid' 'small' 'tiny')! !

!GMStaticMapStandardMarkerGroup methodsFor: 'private' stamp: 'RichardStern 1/3/2011 15:07'!
asUrlParameterOn: aStream
	"Write out receivers representation in an URL-request to Google static 
	maps api on passed stream"

	"Add size, color and character to URL (wth no delimiter!!)- note that latter 
	has to be lowercase - otherwhise default marker is used by google"
	self hasSize ifTrue: 
	[	aStream 
			nextPutAll: 'size:';
			nextPutAll: self size asString.
	].
	self hasColor ifTrue: 
	[	aStream 
			nextPut: $|;
			nextPutAll: 'color:';			
			nextPutAll: self color asString.
	].
	self hasLabel ifTrue: 
	[	aStream 
			nextPut: $|;
			nextPutAll: 'label:';						
			nextPut: self label first asUppercase.
	].
		
	super asUrlParameterOn: aStream.			
! !

!GMStaticMapStandardMarkerGroup methodsFor: 'accessing' stamp: 'rs 12/25/2008 15:55'!
color
	^ color! !

!GMStaticMapStandardMarkerGroup methodsFor: 'accessing' stamp: 'rs 12/25/2008 15:55'!
color: anObject
	color := anObject! !

!GMStaticMapStandardMarkerGroup methodsFor: 'private' stamp: 'rs 12/25/2008 16:12'!
hasColor
	^self color~~nil! !

!GMStaticMapStandardMarkerGroup methodsFor: 'private' stamp: 'RichardStern 12/6/2010 13:05'!
hasLabel

	^(self label isString) and: [self label isEmpty not]
	! !

!GMStaticMapStandardMarkerGroup methodsFor: 'private' stamp: 'rs 3/29/2010 16:11'!
hasSize
	^self size~~nil! !

!GMStaticMapStandardMarkerGroup methodsFor: 'accessing' stamp: 'RichardStern 12/6/2010 13:07'!
label
	^ label! !

!GMStaticMapStandardMarkerGroup methodsFor: 'accessing' stamp: 'RichardStern 12/6/2010 13:07'!
label: anObject
	label := anObject! !

!GMStaticMapStandardMarkerGroup methodsFor: 'accessing' stamp: 'rs 3/29/2010 16:10'!
size
	^ size! !

!GMStaticMapStandardMarkerGroup methodsFor: 'accessing' stamp: 'rs 3/29/2010 16:10'!
size: anObject
	size := anObject! !
